# Owoer

Owoify your text quickly with this "handy" module or (please don't this was my first time making a pip package) copy the code and put it into yours...

## Installation

```
python3 -m pip install owoifyer
```

## Usage

```py
from owoer import owoify

text = "Hello there, how are you on this fine evening?"

owo_text = owoify(text)

print(owo_text)
# Hewwo thewe, how awe you on this finy evenyng?
```

_Yes I was very bored,_

_no I am not a furry._
